@@ -2,40 +2,29 @@
  * 
  * Author: Ian Piumarta <ian.piumarta@squeakland.org>
  * 
- *   Copyright (C) 1996-2005 by Ian Piumarta and other authors/contributors
+ *   Copyright (C) 1996-2007 by Ian Piumarta and other authors/contributors
  *                              listed elsewhere in this file.
  *   All rights reserved.
  *   
- *   This file is part of Unix Squeak.
+ *   Permission is hereby granted, free of charge, to any person obtaining a copy
+ *   of this software and associated documentation files (the "Software"), to deal
+ *   in the Software without restriction, including without limitation the rights
+ *   to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+ *   copies of the Software, and to permit persons to whom the Software is
+ *   furnished to do so, subject to the following conditions:
+ *
+ *   The above copyright notice and this permission notice shall be included in
+ *   all copies or substantial portions of the Software.
+ *
+ *   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ *   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ *   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ *   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ *   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ *   OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+ *   SOFTWARE.
  * 
- *      You are NOT ALLOWED to distribute modified versions of this file
- *      under its original name.  If you modify this file then you MUST
- *      rename it before making your modifications available publicly.
- * 
- *   This file is distributed in the hope that it will be useful, but WITHOUT
- *   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- *   FITNESS FOR A PARTICULAR PURPOSE.
- *   
- *   You may use and/or distribute this file ONLY as part of Squeak, under
- *   the terms of the Squeak License as described in `LICENSE' in the base of
- *   this distribution, subject to the following additional restrictions:
- * 
- *   1. The origin of this software must not be misrepresented; you must not
- *      claim that you wrote the original software.  If you use this software
- *      in a product, an acknowledgment to the original author(s) (and any
- *      other contributors mentioned herein) in the product documentation
- *      would be appreciated but is not required.
- * 
- *   2. You must not distribute (or make publicly available by any
- *      means) a modified copy of this file unless you first rename it.
- * 
- *   3. This notice must not be removed or altered in any source distribution.
- * 
- *   Using (or modifying this file for use) in any context other than Squeak
- *   changes these copyright conditions.  Read the file `COPYING' in the
- *   directory `platforms/unix/doc' before proceeding with any such use.
- * 
- * Last edited: 2006-09-15 11:45:20 by piumarta on wireless-21.media.mit.edu
+ * Last edited: 2008-04-21 14:11:11 by piumarta on emilia
  */
 
 
@@ -106,7 +95,11 @@
 /// No more user-serviceable parts in this file.  Stop Tweaking Now!
 /// 
 
-#define USE_SPINLOCK	1
+#if defined (__ppc__)
+# define USE_SPINLOCK	1
+#else
+# define USE_SPINLOCK	0
+#endif
 #define USE_OWN_ICON	0
 
 static inline int min(int x, int y) { return x < y ? x : y; }
@@ -727,6 +720,47 @@ static sqInt display_ioSetCursorWithMask(sqInt cursorBitsIndex, sqInt cursorMask
   return 1;
 }
 
+static sqInt display_ioSetCursorARGB(sqInt cursorBitsIndex, sqInt extentX, sqInt extentY, sqInt offsetX, sqInt offsetY)
+{
+  if (headless)
+    return 0;
+
+  if ([view lockFocusIfCanDraw])
+    {
+      NSAutoreleasePool *pool= [[NSAutoreleasePool alloc] init];
+      NSBitmapImageRep  *bitmap= 0;
+      NSImage           *image=  0;
+      NSCursor          *cursor= 0;
+
+      bitmap= [[NSBitmapImageRep alloc]
+		initWithBitmapDataPlanes: 0 pixelsWide: extentX pixelsHigh: extentY
+		bitsPerSample: 8 samplesPerPixel: 4
+		hasAlpha: YES isPlanar: NO
+		colorSpaceName: NSCalibratedRGBColorSpace
+		bytesPerRow: extentX * 4
+		bitsPerPixel: 0];
+      {
+	unsigned *planes[5];
+	[bitmap getBitmapDataPlanes: planes];
+	unsigned* src= (unsigned*)cursorBitsIndex;
+	unsigned* dst= planes[0];
+	int i;
+	for (i= 0;  i < extentX * extentY;  ++i, ++dst, ++src)
+	  *dst= (*src & 0xFF00FF00) | ((*src & 0x000000FF) << 16) | ((*src & 0x00FF0000) >> 16);
+      }
+      image= [[NSImage alloc] init];
+      [image addRepresentation: bitmap];
+      {
+	NSPoint hotSpot= { -offsetX, -offsetY };
+	cursor= [[NSCursor alloc] initWithImage: image hotSpot: hotSpot];
+      }
+      [cursor set];
+      [pool release];
+      [view unlockFocus];
+    }
+  return 1;
+}
+
 #if 0
 static sqInt display_ioSetCursor(sqInt cursorBitsIndex, sqInt offsetX, sqInt offsetY)
 {
@@ -1013,6 +1047,24 @@ static sqInt display_clipboardReadIntoAt(sqInt count, sqInt byteArrayIndex, sqIn
   return 0;
 }
 
+static char **display_clipboardGetTypeNames(void)
+{
+  return 0;
+};
+
+static sqInt display_clipboardSizeWithType(char *typeName, int ntypeName)
+{
+  return 0;
+}
+
+static void display_clipboardWriteWithType(char *data, size_t nData, char *typeName, size_t nTypeName, int isDnd, int isClaiming)
+{
+  return;
+}
+
+static sqInt display_dndOutStart(char *types, int ntypes)	{ return 0; }
+static void  display_dndOutSend(char *bytes, int nbytes)	{ return  ; }
+static sqInt display_dndOutAcceptedType(char * buf, int nbuf)	{ return 0; }
 
 static void display_winExit(void)
 {
@@ -1263,6 +1315,7 @@ static void setUpWindow(int fs)
       NSRect contentRect;
       if (fs)
 	{
+	  setUpDisplay();
 	  w= dpyWidth;
 	  h= dpyHeight;
 	}
@@ -1688,6 +1741,7 @@ static void *runInterpreter(void *arg)
   (void)recordMouseEvent;
   (void)recordKeyboardEvent;
   (void)recordDragEvent;
+  (void)recordWindowEvent;
 }
 
 
